import 'dart:async';
import 'package:get/get.dart';
import 'package:mypoint_flutter_app/base/base_response_model.dart';
import 'otp_verify_response_model.dart';

// i_otp_repository.dart
abstract class IOtpRepository {
  Future<void> sendOtp();
  Future<BaseResponseModel<OTPVerifyResponseModel>> verifyOtp(String otpCode);
  Future<void> resendOtp();
  late String phoneNumber;
}

class OtpViewModel extends GetxController {
  final IOtpRepository repository;
  var otpCode = "".obs;
  var errorMessage = "".obs;
  var currentCountdown = 0.obs;
  final int _maxCountdown = 150; // 2 phút 30 giây
  Timer? _timer;

  OtpViewModel(this.repository);

  @override
  void onInit() {
    super.onInit();
    sendOtp();
    startCountdown();
  }

  @override
  void onClose() {
    _timer?.cancel();
    super.onClose();
  }

  Future<void> sendOtp() async {
    try {
      await repository.sendOtp();
      startCountdown();
    } catch (e) {
      errorMessage.value = "Gửi OTP thất bại. Vui lòng thử lại.";
    }
  }

  void startCountdown() {
    currentCountdown.value = _maxCountdown;
    _timer?.cancel();
    _timer = Timer.periodic(const Duration(seconds: 1), (timer) {
      if (currentCountdown.value <= 0) {
        timer.cancel();
      } else {
        currentCountdown.value--;
      }
    });
  }

  String get countdownText {
    final m = currentCountdown.value ~/ 60;
    final s = currentCountdown.value % 60;
    final sStr = s < 10 ? "0$s" : "$s";
    return "$m:$sStr";
  }

  void onOtpChanged(String value) {
    otpCode.value = value;
    errorMessage.value = "";
  }

  Future<void> onSubmitOtp() async {
    if (otpCode.value.length < 6) {
      errorMessage.value = "Nhập đủ 6 ký tự";
      return;
    }
    try {
      final response = await repository.verifyOtp(otpCode.value);
      if (response.isSuccess) {
        errorMessage.value = "response.isSuccess";
      } else {
        errorMessage.value = response.errorMessage ?? "";
      }
    } catch (e) {
      // Bắt lỗi do repository throw
      errorMessage.value = "Xác thực thất bại: $e";
    }
  }

  Future<void> onResendOtp() async {
    if (currentCountdown.value > 0) return;
    try {
      await repository.resendOtp();
      startCountdown();
    } catch (e) {
      errorMessage.value = "Gửi lại OTP thất bại. Thử lại.";
    }
  }
}